@@ -107,11 +107,6 @@ enum {
 
 struct _GtkSourceBufferPrivate
 {
-	gint                   highlight_syntax:1;
-	gint                   highlight_brackets:1;
-
-	gint                   constructed:1;
-
 	GtkTextTag            *bracket_match_tag;
 	GtkTextMark           *bracket_mark_cursor;
 	GtkTextMark           *bracket_mark_match;
@@ -127,16 +122,16 @@ struct _GtkSourceBufferPrivate
 	GtkSourceUndoManager  *undo_manager;
 	gint                   max_undo_levels;
 
-	gint                   allow_bracket_match:1;
+	guint                  highlight_syntax : 1;
+	guint                  highlight_brackets : 1;
+	guint                  constructed : 1;
+	guint                  allow_bracket_match : 1;
 };
 
 G_DEFINE_TYPE (GtkSourceBuffer, gtk_source_buffer, GTK_TYPE_TEXT_BUFFER)
 
 static guint 	 buffer_signals[LAST_SIGNAL];
 
-static GObject	*gtk_source_buffer_constructor		(GType                    type,
-							 guint                    n_construct_properties,
-							 GObjectConstructParam   *construct_param);
 static void 	 gtk_source_buffer_finalize		(GObject                 *object);
 static void 	 gtk_source_buffer_dispose		(GObject                 *object);
 static void      gtk_source_buffer_set_property         (GObject                 *object,
@@ -183,6 +178,23 @@ static gboolean	 gtk_source_buffer_find_bracket_match_with_limit (GtkSourceBuffe
 static void	 gtk_source_buffer_real_undo		(GtkSourceBuffer	 *buffer);
 static void	 gtk_source_buffer_real_redo		(GtkSourceBuffer	 *buffer);
 
+static void
+gtk_source_buffer_constructed (GObject *object)
+{
+	GtkSourceBuffer *buffer = GTK_SOURCE_BUFFER (object);
+
+	/* we need to know that the tag-table was set */
+	buffer->priv->constructed = TRUE;
+
+	if (buffer->priv->undo_manager == NULL)
+	{
+		/* This will install the default undo manager */
+		gtk_source_buffer_set_undo_manager (buffer, NULL);
+	}
+
+	G_OBJECT_CLASS (gtk_source_buffer_parent_class)->constructed (object);
+}
+
 static void
 gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 {
@@ -193,7 +205,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	object_class 	= G_OBJECT_CLASS (klass);
 	tb_class	= GTK_TEXT_BUFFER_CLASS (klass);
 
-	object_class->constructor  = gtk_source_buffer_constructor;
+	object_class->constructed  = gtk_source_buffer_constructed;
 	object_class->finalize	   = gtk_source_buffer_finalize;
 	object_class->dispose	   = gtk_source_buffer_dispose;
 	object_class->get_property = gtk_source_buffer_get_property;
@@ -446,31 +458,6 @@ gtk_source_buffer_init (GtkSourceBuffer *buffer)
 		g_object_ref (priv->style_scheme);
 }
 
-static GObject *
-gtk_source_buffer_constructor (GType                  type,
-			       guint                  n_construct_properties,
-			       GObjectConstructParam *construct_param)
-{
-	GObject *object;
-	GtkSourceBuffer *buffer;
-
-	object = G_OBJECT_CLASS(gtk_source_buffer_parent_class)->constructor (type,
-									      n_construct_properties,
-									      construct_param);
-
-	/* we need to know that the tag-table was set */
-	buffer = GTK_SOURCE_BUFFER (object);
-	buffer->priv->constructed = TRUE;
-
-	if (buffer->priv->undo_manager == NULL)
-	{
-		/* This will install the default undo manager */
-		gtk_source_buffer_set_undo_manager (buffer, NULL);
-	}
-
-	return object;
-}
-
 static void
 gtk_source_buffer_finalize (GObject *object)
 {
@@ -1091,7 +1078,7 @@ gtk_source_buffer_find_bracket_match_real (GtkSourceBuffer           *buffer,
 
 	cur_char = gtk_text_iter_get_char (&iter);
 
-	base_char = search_char = cur_char;
+	base_char = cur_char;
 	cclass_mask = get_context_class_mask (buffer, &iter);
 
 	search_char = bracket_pair (base_char, &addition);
